==> parody_1.2.0.zip: parody/doc/parody.R <==
###################################################
### chunk number 1: rune
###################################################
library(parody)


###################################################
### chunk number 2: 
###################################################
options(width=56)


###################################################
### chunk number 3: run32
###################################################
lead <- c(83, 70, 62, 55, 56, 57, 57, 58, 59, 50, 51, 
        52, 52, 52, 54, 54, 45, 46, 48,
        48, 49, 40, 40, 41, 42, 42, 44, 
        44, 35, 37, 38, 38, 34, 13, 14)


###################################################
### chunk number 4: dobo
###################################################
boxplot(lead)


###################################################
### chunk number 5: dob1
###################################################
calout.detect(lead,alpha=.05,method="boxplot", scaling=
function(n,alpha)1.5)


###################################################
### chunk number 6: dobi
###################################################
calout.detect(lead,alpha=.05,method="boxplot",ftype="ideal")


###################################################
### chunk number 7: dor
###################################################
calout.detect(lead,alpha=.05,method="GESD",k=5)


###################################################
### chunk number 8: dha
###################################################
calout.detect(lead,alpha=.05,method="medmad",scaling=hamp.scale.3)


###################################################
### chunk number 9: dos
###################################################
calout.detect(lead,alpha=.05,method="shorth")


###################################################
### chunk number 10: dot
###################################################
data(tcost)
ostr = mv.calout.detect(tcost)
ostr


###################################################
### chunk number 11: dop
###################################################
thecol = rep("black", nrow(tcost))
thecol[ostr$ind] = "red"


###################################################
### chunk number 12: dopr
###################################################
pairs(tcost, col=thecol, pch=19)


###################################################
### chunk number 13: dopc
###################################################
pc = prcomp(tcost)


###################################################
### chunk number 14: dobip
###################################################
biplot(pc)


###################################################
### chunk number 15: dor
###################################################
ftcost = tcost[-c(9,21),]
fpc = prcomp(ftcost)


###################################################
### chunk number 16: rfig
###################################################
biplot(fpc)

==> parody_1.8.0.zip: parody/doc/parody.R <==
###################################################
### chunk number 1: rune
###################################################
#line 94 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
library(parody)


###################################################
### chunk number 2: 
###################################################
#line 96 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
options(width=56)


###################################################
### chunk number 3: run32
###################################################
#line 102 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
lead <- c(83, 70, 62, 55, 56, 57, 57, 58, 59, 50, 51, 
        52, 52, 52, 54, 54, 45, 46, 48,
        48, 49, 40, 40, 41, 42, 42, 44, 
        44, 35, 37, 38, 38, 34, 13, 14)


###################################################
### chunk number 4: dobo
###################################################
#line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
boxplot(lead)


###################################################
### chunk number 5: dob1
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
calout.detect(lead,alpha=.05,method="boxplot", scaling=
function(n,alpha)1.5)


###################################################
### chunk number 6: dobi
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
calout.detect(lead,alpha=.05,method="boxplot",ftype="ideal")


###################################################
### chunk number 7: dor
###################################################
#line 145 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
calout.detect(lead,alpha=.05,method="GESD",k=5)


###################################################
### chunk number 8: dha
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
calout.detect(lead,alpha=.05,method="medmad",scaling=hamp.scale.3)


###################################################
### chunk number 9: dos
###################################################
#line 158 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
calout.detect(lead,alpha=.05,method="shorth")


###################################################
### chunk number 10: dot
###################################################
#line 168 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
data(tcost)
ostr = mv.calout.detect(tcost)
ostr


###################################################
### chunk number 11: dop
###################################################
#line 175 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
thecol = rep("black", nrow(tcost))
thecol[ostr$ind] = "red"


###################################################
### chunk number 12: dopr
###################################################
#line 181 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
pairs(tcost, col=thecol, pch=19)


###################################################
### chunk number 13: dopc
###################################################
#line 187 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
pc = prcomp(tcost)


###################################################
### chunk number 14: dobip
###################################################
#line 192 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
biplot(pc)


###################################################
### chunk number 15: dor
###################################################
#line 203 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
ftcost = tcost[-c(9,21),]
fpc = prcomp(ftcost)


###################################################
### chunk number 16: rfig
###################################################
#line 209 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp0htuDc/R.INSTALL310d4b8/parody/inst/doc/parody.Rnw"
biplot(fpc)
